require 'spec_helper'

describe BeanstalkFarmer::Config do
  its(:host) { should == described_class::DEFAULT_HOST }

  its(:port) { should == described_class::DEFAULT_PORT }

  its(:logger) { should be_a(Logger) }

  its(:json_engine) { should == MultiJson.engine }

  describe ".option" do
    before(:all) do
      described_class.option(:test_setting, default: true)
    end

    it "creates a getter for an option" do
      described_class.should respond_to(:test_setting)
    end

    it "creates a setter for the option" do
      described_class.should respond_to(:test_setting=)
    end

    it "creates a conditional for the option" do
      described_class.should respond_to(:test_setting?)
    end

    it "allows the setting of a default value" do
      described_class.test_setting.should == true
    end
  end

  describe '#json_engine' do
    it 'is the engine set for MultiJson' do
      described_class.json_engine.should == MultiJson.engine
    end
  end

  describe '#json_engine=' do
    it 'sets the JSON engine of choice on MultiJson' do
      MultiJson.should_receive(:engine=).with(:yajl)
      described_class.json_engine = :yajl
    end
  end
end
