require 'spec_helper'

describe BeanstalkFarmer::Runner do
  subject { described_class.new }

  its(:service) { should be_a_kind_of(BeanstalkFarmer::Service) }

  describe '#initialize' do
    its(:handler_pool) { should be_a(Hash) }
  end

  describe '#prep_tubes' do
    it 'prepares tubes for watching'  do
      subject.service.should_receive(:prep).with(subject.handler_pool.keys)
      subject.prep_tubes
    end
  end

  describe '#reserve_and_work_job' do
    let(:timeout) { 45 }

    it 'tells the service to reserve and work a job' do
      subject.service.should_receive(:reserve_and_work_job).with(timeout)
      subject.reserve_and_work_job(timeout)
    end
  end

  describe '#run!' do
    before(:each) do
      subject.stub(:prep_tubes)
      subject.stub(:work_jobs)
    end

    it 'prepares tubes for watching' do
      subject.should_receive(:prep_tubes)
      subject.run!
    end

    it 'works jobs' do
      subject.should_receive(:work_jobs)
      subject.run!
    end
  end

  describe '#close_connection' do
    it 'closes the connection to the service' do
      subject.service.should_receive(:close)
      subject.close_connection
    end
  end
end
