require 'spec_helper'

class ReleaseWorker
  LIMIT = 2

  @@count = 0

  def self.call(args)
    if @@count < LIMIT
      $stderr << "Count: #{@@count}"
      @@count += 1
      [:release]
    else
      $stderr << args
    end
  end
end unless defined?(ReleaseWorker)

describe 'Workers do work', :beanstalk_required do
  let!(:service) { BeanstalkFarmer::Service.new }

  let!(:runner) { BeanstalkFarmer::Runner.new }

  let(:final_message) { 'Hello. Finally done.' }

  before(:each) do
    @old_stderr = $stderr
    @capture    = StringIO.new
    $stderr     = @capture

    runner.register_handlers do
      tube 'echo.release', ReleaseWorker
    end

    runner.prep_tubes
    service.enqueue 'echo.release', final_message
  end

  after(:each) do
    $stderr  = @old_stderr
    @capture = nil
    service.close
  end

  it 'does work with special post-job effects' do
    ReleaseWorker::LIMIT.times do |n|
      runner.reserve_and_work_job

      if n < ReleaseWorker::LIMIT
        @capture.string.should == "Count: #{n}"
        @capture.rewind
      else
        @capture.string.should == final_message
      end
    end
  end
end
