require 'spec_helper'

class ClassWorker
  def self.call(args)
    $stderr << args
  end
end unless defined?(ClassWorker)

describe 'Workers do work', :beanstalk_required do
  let!(:service) { BeanstalkFarmer::Service.new }

  let!(:runner) { BeanstalkFarmer::Runner.new }

  before(:each) do
    @old_stderr = $stderr
    @capture    = StringIO.new
    $stderr     = @capture

    runner.register_handlers do
      tube 'echo.small_proc', proc { |args| $stderr << args }
      tube 'echo.big_proc',   Proc.new { |args| $stderr << args }
      tube 'echo.class',      ClassWorker
      tube 'echo.block',      do |args| $stderr << args; end
    end

    runner.prep_tubes
  end

  after(:each) do
    $stderr  = @old_stderr
    @capture = nil
    service.close
  end

  it 'performs enqueued work with small procs' do
    message = 'Hello, proc'
    service.enqueue 'echo.small_proc', message
    runner.reserve_and_work_job

    @capture.string.should == message
  end

  it 'performs enqueued work with blocks' do
    message = 'Hello, block'
    service.enqueue 'echo.block', message
    runner.reserve_and_work_job

    @capture.string.should == message
  end

  it 'performs enqueued work with big procs' do
    message = 'Hello, big Proc'
    service.enqueue 'echo.big_proc', message
    runner.reserve_and_work_job

    @capture.string.should == message
  end

  it 'performs enqueued work with class' do
    message = 'Hello, Class'
    service.enqueue 'echo.class', message
    runner.reserve_and_work_job

    @capture.string.should == message
  end
end
